Blazar, the OpenStack Reservation Service
=========================================

Blazar is an OpenStack service to provide resource reservations in the
OpenStack cloud for different resource types - both virtual (instances,
volumes, stacks) and physical (hosts).

User Guide
----------

.. toctree::
    :maxdepth: 2

    user/index

Admin Guide
-----------

.. toctree::
    :maxdepth: 2

    admin/index

Installation Guide
------------------

.. toctree::
   :maxdepth: 2

   install/index

Configuration Reference
-----------------------
.. toctree::
   :maxdepth: 2

   configuration/index

CLI Reference
-------------

.. toctree::
   :maxdepth: 2

   cli/index

API Reference
-------------

.. toctree::
   :maxdepth: 2

   restapi/index


For Contributors
----------------

.. toctree::
   :maxdepth: 2

   contributor/index

Specs
-----

.. toctree::
   :maxdepth: 2

   specs/index

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`
